@@ -7,7 +7,7 @@ def find_files(folder_path, file_extension):
     for file_name in os.listdir(folder_path):
         if file_name.endswith('.' + file_extension):
             file_names.append(file_name)
-    return file_names
+    return sorted(file_names)
 
 def find_files_with_same_name(folder_paths, file_extensions):
     # return a list of the files that are in all the folders and have the same name, without the extension
